<!-- This file is generated. DO NOT EDIT -->

# uv

uv is a Python package and project manager.

See the [documentation](https://docs.astral.sh/uv/) or [repository](https://github.com/astral-sh/uv)
for more information.

This crate is the entry point to the uv command-line interface. The Rust API exposed here is not
considered public interface.

This is version 0.11.10. The source can be found
[here](https://github.com/astral-sh/uv/blob/0.11.10/crates/uv).

The following uv workspace members are also available:

- [uv-audit](https://crates.io/crates/uv-audit)
- [uv-auth](https://crates.io/crates/uv-auth)
- [uv-bin-install](https://crates.io/crates/uv-bin-install)
- [uv-build](https://crates.io/crates/uv-build)
- [uv-build-backend](https://crates.io/crates/uv-build-backend)
- [uv-build-frontend](https://crates.io/crates/uv-build-frontend)
- [uv-cache](https://crates.io/crates/uv-cache)
- [uv-cache-info](https://crates.io/crates/uv-cache-info)
- [uv-cache-key](https://crates.io/crates/uv-cache-key)
- [uv-cli](https://crates.io/crates/uv-cli)
- [uv-client](https://crates.io/crates/uv-client)
- [uv-configuration](https://crates.io/crates/uv-configuration)
- [uv-console](https://crates.io/crates/uv-console)
- [uv-dirs](https://crates.io/crates/uv-dirs)
- [uv-dispatch](https://crates.io/crates/uv-dispatch)
- [uv-distribution](https://crates.io/crates/uv-distribution)
- [uv-distribution-filename](https://crates.io/crates/uv-distribution-filename)
- [uv-distribution-types](https://crates.io/crates/uv-distribution-types)
- [uv-extract](https://crates.io/crates/uv-extract)
- [uv-fastid](https://crates.io/crates/uv-fastid)
- [uv-flags](https://crates.io/crates/uv-flags)
- [uv-fs](https://crates.io/crates/uv-fs)
- [uv-git](https://crates.io/crates/uv-git)
- [uv-git-types](https://crates.io/crates/uv-git-types)
- [uv-globfilter](https://crates.io/crates/uv-globfilter)
- [uv-install-wheel](https://crates.io/crates/uv-install-wheel)
- [uv-installer](https://crates.io/crates/uv-installer)
- [uv-keyring](https://crates.io/crates/uv-keyring)
- [uv-logging](https://crates.io/crates/uv-logging)
- [uv-macros](https://crates.io/crates/uv-macros)
- [uv-metadata](https://crates.io/crates/uv-metadata)
- [uv-normalize](https://crates.io/crates/uv-normalize)
- [uv-once-map](https://crates.io/crates/uv-once-map)
- [uv-options-metadata](https://crates.io/crates/uv-options-metadata)
- [uv-pep440](https://crates.io/crates/uv-pep440)
- [uv-pep508](https://crates.io/crates/uv-pep508)
- [uv-performance-memory-allocator](https://crates.io/crates/uv-performance-memory-allocator)
- [uv-platform](https://crates.io/crates/uv-platform)
- [uv-platform-tags](https://crates.io/crates/uv-platform-tags)
- [uv-preview](https://crates.io/crates/uv-preview)
- [uv-publish](https://crates.io/crates/uv-publish)
- [uv-pypi-types](https://crates.io/crates/uv-pypi-types)
- [uv-python](https://crates.io/crates/uv-python)
- [uv-redacted](https://crates.io/crates/uv-redacted)
- [uv-requirements](https://crates.io/crates/uv-requirements)
- [uv-requirements-txt](https://crates.io/crates/uv-requirements-txt)
- [uv-resolver](https://crates.io/crates/uv-resolver)
- [uv-scripts](https://crates.io/crates/uv-scripts)
- [uv-settings](https://crates.io/crates/uv-settings)
- [uv-shell](https://crates.io/crates/uv-shell)
- [uv-small-str](https://crates.io/crates/uv-small-str)
- [uv-state](https://crates.io/crates/uv-state)
- [uv-static](https://crates.io/crates/uv-static)
- [uv-test](https://crates.io/crates/uv-test)
- [uv-tool](https://crates.io/crates/uv-tool)
- [uv-torch](https://crates.io/crates/uv-torch)
- [uv-trampoline-builder](https://crates.io/crates/uv-trampoline-builder)
- [uv-types](https://crates.io/crates/uv-types)
- [uv-unix](https://crates.io/crates/uv-unix)
- [uv-version](https://crates.io/crates/uv-version)
- [uv-virtualenv](https://crates.io/crates/uv-virtualenv)
- [uv-warnings](https://crates.io/crates/uv-warnings)
- [uv-windows](https://crates.io/crates/uv-windows)
- [uv-workspace](https://crates.io/crates/uv-workspace)

uv's workspace members are considered internal and will have frequent breaking changes.

See uv's
[crate versioning policy](https://docs.astral.sh/uv/reference/policies/versioning/#crate-versioning)
for details on versioning.
